.. image:: https://badge.fury.io/py/bitcoinX.svg
    :target: http://badge.fury.io/py/bitcoinX

===========
py-asqlite3
===========

A simple and lightweight async wrapper of everything from the built-in sqlite3.

  :Licence: MIT
  :Language: Python (>= 3.8)
  :Author: Neil Booth


Documentation
=============

See `readthedocs <https://py-asqlite3.readthedocs.io/>`_.


**Neil Booth**  kyuupichan@pm.me  https://github.com/kyuupichan


ChangeLog
=========

0.5.0
-----

Close to release state.  Docs and some more testcases needed.
